from setuptools import setup

setup(name='my_statistical_distributions',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['my_statistical_distributions'],
      author='Timo Hartmann',
      author_email='timo.hartmann@posteo.de',
      zip_safe=False)
